/*
  This file is part of ccbuild.

  ccbuild is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  ccbuild is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with ccbuild.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "system.ih"

std::string System::mkdtemp(std::string const& nameTemplate)
{
  char * tmpDirName = new char[nameTemplate.size() +1];
  tmpDirName[nameTemplate.size()] = '\0';
  ::strcpy(tmpDirName, nameTemplate.c_str());
  char const* tmpDir = ::mkdtemp(tmpDirName);

  if(tmpDir == 0)
  {
    delete[] tmpDirName;
    throw Problem(Problem::Unable, "Unable to create a temporary directory for batch compilation");
  }
  //Do I delete the modified version? I guess so
  std::string dirname(tmpDirName);
  delete[] tmpDirName;
  return dirname;
}
